# Changelog

## 0.1.0 (2025-04-15)

*   Initial release.
*   Added `ChallengeClient` with methods for datasets and submissions.
*   Added CLI interface (`crowdcent-challenge`).
*   Added basic documentation with MkDocs. 